@@ -167,7 +167,7 @@ searchCrossOverDesignCTest <- function() {
   C <- as.matrix(bdiag(Csub,Csub))  
   CC <- t(C) %*% C
   H <- linkMatrix(model, v)
-  .Call( "searchCOD", s, p, v, design, H, CC, model, eff.factor, v.rep, balance.s, balance.p, verbose, 50000, PACKAGE = "Crossover" )
+  #.Call( "searchCOD", s, p, v, design, H, CC, model, eff.factor, v.rep, balance.s, balance.p, verbose, 50000, PACKAGE = "Crossover" )
 }
 
 searchCrossOverDesign_R <- function(s, p, v, model="Standard additive model", eff.factor, v.rep, balance.s=FALSE, balance.p=FALSE, verbose=FALSE, ppp=0.5, placebos=1) {
